/*   This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; version 2 of the License.
   
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
     
     (C) 2006 schan
*/
#include "history.h"
#include <iostream>
#include <fstream>

#define HISTORY_FILE "history.dat"

History::History()
{
}

void History::load()
{
	files.clear();
	
	std::ifstream file(HISTORY_FILE);
	if (file.is_open())
	{
		std::string line;
		while (!file.eof() )
		{
			std::getline(file,line);		
			if (line.length()>0)
			{
				int sep = line.find(" ",0);
				
				HistoryItem it;
				it.percent = atof(line.substr(0,sep).c_str());
				it.filename = line.substr(sep+1,line.length()-sep-1);
				
				files.push_back(it);
			}
			
		}
		file.close();		
	}
	
}


void History::add(const std::string &filename, float percent)
{
	// if item is already in the vector, modify it
	int found = -1;
	for (int i=0; i<files.size(); i++)
	{
		if (files.at(i).filename==filename)
		{
			found = i;
		}
	}

	// create new item
	HistoryItem item;
	item.filename = filename;
	item.percent = percent;	
	files.push_back(item);

	if (found!=-1) // erase previous ocurrence
	{
		files.erase(files.begin()+found);
	}
	

	// save last 5 items

	std::ofstream file(HISTORY_FILE);

	int first = files.size()-5;
	if (first<0) first = 0;
	
	for (int i=first; i<files.size(); i++)
	{
	    file << files.at(i).percent << " " << files.at(i).filename << std::endl;		    
	}
	file.close();	
	
	// reload (refresh)
	load();
}

