/*   This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; version 2 of the License.
   
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
     
     (C) 2006 schan
*/
#ifndef PLAINTEXT_H
#define PLAINTEXT_H

#include "SDL/SDL.h"
#include <string>
#include <vector>
#include "bitmapfont.h"
#include "text.h"
#include "options.h"

struct Glyph
{
	Uint16 unicode_char;
	int x;
};
		
class LineInfo
{
	public:
		LineInfo();
		~LineInfo();
		static void set_max_width(int w);
		static void set_font(BitmapFont *f);
		static void set_justify(bool j);
		static void set_space_char(Uint16 c);
		
		int process_text(Uint16 *unicode_text, int begin);
		// returns index of the first Uint16 NOT added,
		// or NULL if all are added
		
		void set_text(Uint16 *unicode_text, int begin, int end, bool needs_justify);
		void render(SDL_Surface *dest, int x, int y);
		
		
	private:
		static int max_width;
		static BitmapFont *font;
		static bool justify;
		static Uint16 space_char;
		
		bool needs_justify;
		bool formatted;
		void format();

		Glyph *glyphs;
		int num_glyphs;
};


class PlainTextRenderer : public TextRenderer
{
	public:
	
		PlainTextRenderer(Options *options);
		~PlainTextRenderer();
				
		void reset();

		void set_font(BitmapFont *f);
		void set_viewport_width(int w);
		void set_viewport_height(int h);
	
		void add_line(std::string line, int encoding);

		void render(SDL_Surface *dest);

		void next_line();
		void prev_line();
		void next_page();
		void prev_page();
		void go_to_line(unsigned long int n);
		void go_to_percent(float p);
		float get_percent();

		
	protected:
		std::vector<LineInfo *> lines; 

		int width;
		int height;
		int visible_lines;

		long int scroll_y;
		long int max_scroll;

		Options *options;
		BitmapFont *font;

		void scroll_by(int n);

		
};


#endif
