/*   This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; version 2 of the License.
   
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
     
     (C) 2006 schan
*/
#include "SDL/SDL.h"
#include "defines.h"
#include "gui_skin.h"
#include "widget_font.h"
#include "bitmapfont.h"
#include "util.h"
#include "translation.h"
#include <vector>

#define TEST_TEXT "ABC 123 def Ghi"

char *FontWidget::preview_text = Translation::get(Translation::TXT_PREVIEW);

FontWidget::FontWidget(const std::string &name)
{
	img = NULL;
	this->name = name;
	set_text1(util::utf8_to_unicode(this->name.c_str()),true);
	set_text2(util::utf8_to_unicode(preview_text),true);
}

FontWidget::~FontWidget()
{
	if (img!=NULL) SDL_FreeSurface(img);
}


bool FontWidget::on_button_down(int button)
{
	if (button==GP2X_BUTTON_A && img==NULL)
	{
		// load font;
		std::string s = "fonts/"+name+".bmp";
		BitmapFont f;
		f.load(s.c_str(),CHAR_LIST);
		set_text2(NULL,false);
		img = SDL_CreateRGBSurface(SDL_SWSURFACE, 
		                           f.get_width(TEST_TEXT)+2, f.get_height(), 32,
		                           0x000000ff, 0x0000ff00, 0x00ff0000, 0xff000000);
		f.draw_text(TEST_TEXT,img, 2,0, false, false);		                         
		font_bg = f.get_bg_color();
		
		return true;
	}
	else if (button==GP2X_BUTTON_B)
	{
		return true;
	}
	else return false;
}

void FontWidget::draw_custom_content(SDL_Surface *dest, int x, int y, int w, bool selected)
{
	if (img!=NULL && selected)
	{
		SDL_Rect dest_rect = {x+2, y, w-4, img->h};
		
		SDL_FillRect(dest,&dest_rect,SDL_MapRGB(dest->format,font_bg.r, font_bg.g, font_bg.b));
		SDL_BlitSurface(img,NULL,dest,&dest_rect);				
	}

}

int FontWidget::get_custom_content_height(bool selected)
{
	return (img==NULL || !selected ? 0 : img->h );
}

void FontWidget::refresh_lang()
{
	FontWidget::preview_text = Translation::get(Translation::TXT_PREVIEW);
}
